# eric7.Network.IRC.IrcMessageEdit

Module implementing a specialized line edit for entering IRC messages.

### Global Attributes

None

### Classes

IrcMessageEdit | Class implementing a specialized line edit for entering IRC messages.

### Functions

None

## IrcMessageEdit

Class implementing a specialized line edit for entering IRC messages.

### Derived from

QLineEdit

### Class Attributes

MaxHistory

### Class Methods

None

### Methods

IrcMessageEdit | Constructor
__addHistory | Private method to add an entry to the history.
__getHistory | Private method to move in the history.
keyPressEvent | Protected method implementing special key handling.
setText | Public method to set the text.
wheelEvent | Protected slot to support wheel events.

### Static Methods

None

#### IrcMessageEdit (Constructor)

IrcMessageEdit(parent=None)

Constructor

parent (QWidget)
  reference to the parent widget

#### IrcMessageEdit.__addHistory

__addHistory(txt)

Private method to add an entry to the history.

txt (str)
  text to be added to the history

#### IrcMessageEdit.__getHistory

__getHistory(up)

Private method to move in the history.

up (bool)
  flag indicating the direction

#### IrcMessageEdit.keyPressEvent

keyPressEvent(evt)

Protected method implementing special key handling.

evt (QKeyEvent)
  reference to the event

#### IrcMessageEdit.setText

setText(text)

Public method to set the text.

Note: This reimplementation ensures, that the cursor is at the end of the text.

text (str)
  text to be set

#### IrcMessageEdit.wheelEvent

wheelEvent(evt)

Protected slot to support wheel events.

evt (QWheelEvent)
  reference to the wheel event

Up